Welcome to Pygame Turbo
=======================

Pygame Turbo is for creating games without boilerplate.

It is intended for use in education, so that teachers can teach basic
programming without needing to explain the Pygame API or write an event loop.

Pygame Turbo is a fast moving fork of the Pygame Zero framework created by
Daniel Pope.


Courses
-------

.. toctree::
    :maxdepth: 2

    introduction
    from-scratch

.. This one is not yet complete
.. learn-programming
.. flappy-bird

Reference
---------

.. toctree::
    :maxdepth: 3

    hooks
    builtins

User Guide
----------

.. toctree::
    :maxdepth: 2

    installation
    ide-mode
    examples
    resources
    other-libs
    changelog


Improving Pygame Turbo
----------------------

.. toctree::
    :maxdepth: 2

    roadmap
    principles
    contributing
